# cli_color_palette

wip

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install cli_color_palette:

```bash
pip install color_palette_cli
```

## Usage

```
   $ wip
```

## Tests
You will need a [pytest](https://pypi.org/project/pytest/) library to run tests. After installation of said module, run this command in a directory where the color_palette_at library is located:
```
pytest
```
To run all the tests.

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)